@@ -99,7 +99,7 @@ class Book(models.Model):
     sellsheet = models.FileField(upload_to='/books', blank=True)
     amazon = models.CharField(max_length=100, blank=True, null=True, default='')
     description = models.TextField(blank=True)
-    blurb = models.TextField(blank=True)
+    blurb = RichTextField(blank=True)
     bigtext = RichTextField(blank=True,null=True)
     descriptionlong = models.TextField(blank=True)
     authornotes = models.TextField(blank=True)
